@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "4.3.0"
+#define BARESIP_VERSION "4.5.0"
 
 
 #ifndef NET_MAX_NS
@@ -94,6 +94,7 @@ int account_json_api(struct odict *odacc, struct odict *odcfg,
 int account_set_auth_user(struct account *acc, const char *user);
 int account_set_auth_pass(struct account *acc, const char *pass);
 int account_set_outbound(struct account *acc, const char *ob, unsigned ix);
+void account_set_check_origin(struct account *acc, bool value);
 int account_set_sipnat(struct account *acc, const char *sipnat);
 int account_set_answermode(struct account *acc, enum answermode mode);
 int account_set_rel100_mode(struct account *acc, enum rel100_mode mode);
@@ -137,6 +138,7 @@ const char *account_aor(const struct account *acc);
 const char *account_auth_user(const struct account *acc);
 const char *account_auth_pass(const struct account *acc);
 const char *account_outbound(const struct account *acc, unsigned ix);
+bool account_check_origin(const struct account *acc);
 const char *account_sipnat(const struct account *acc);
 const char *account_stun_user(const struct account *acc);
 const char *account_stun_pass(const struct account *acc);
@@ -162,7 +164,7 @@ void account_set_sip_autoredirect(struct account *acc, bool allow);
 enum sipansbeep account_sipansbeep(const struct account *acc);
 void account_set_sipansbeep(struct account *acc, enum sipansbeep beep);
 void account_set_autelev_pt(struct account *acc, uint32_t pt);
-uint32_t account_autelev_pt(struct account *acc);
+uint32_t account_autelev_pt(const struct account *acc);
 const char* account_uas_user(const struct account *acc);
 const char* account_uas_pass(const struct account *acc);
 bool account_uas_isset(const struct account *acc);
@@ -271,6 +273,7 @@ int32_t       call_answer_delay(const struct call *call);
 void          call_set_answer_delay(struct call *call, int32_t adelay);
 struct call  *call_find_linenum(const struct list *calls, uint32_t linenum);
 struct call  *call_find_id(const struct list *calls, const char *id);
+struct call  *call_find_id_pl(const struct list *calls, const struct pl *id);
 void call_set_current(struct list *calls, struct call *call);
 const struct list *call_get_custom_hdrs(const struct call *call);
 void call_set_media_direction(struct call *call, enum sdp_dir a,
@@ -282,13 +285,43 @@ void call_get_media_estdir(struct call *call,
 			   enum sdp_dir *ap, enum sdp_dir *vp);
 void call_start_answtmr(struct call *call, uint32_t ms);
 bool          call_supported(struct call *call, uint16_t tags);
-const char   *call_user_data(const struct call *call);
-int call_set_user_data(struct call *call, const char *user_data);
+const struct pl *call_user_data(const struct call *call);
+int call_set_user_data(struct call *call, const struct pl *user_data);
 int call_msg_src(const struct call *call, struct sa *sa);
 enum sip_transp call_transp(const struct call *call);
 enum sdp_neg_state call_sdp_neg_state(const struct call *call);
 bool call_sdp_change_allowed(const struct call *call);
 
+/**
+ * Command parameter parse helpers
+ */
+
+int cparam_decode(const char *prm, const char *name, struct pl *val);
+
+/** UA command parameters */
+struct cparam_ua {
+	struct pl dname;              /**< Display name                   */
+	struct pl uri;	              /**< SIP URI                        */
+	struct pl cuser;              /**< Contact user                   */
+	enum sdp_dir adir;            /**< Audio direction                */
+	enum sdp_dir vdir;            /**< Video direction                */
+	struct pl userdata;           /**< User data                      */
+};
+
+int cparam_ua_decode(struct cparam_ua **prmp,
+		     const char *prm, struct re_printf *pf);
+
+/** Call command parameters */
+struct cparam_call {
+	struct pl callid;             /**< Call-ID                        */
+	enum sdp_dir adir;            /**< Audio direction                */
+	enum sdp_dir vdir;            /**< Video direction                */
+	bool mdir;                    /**< Media direction flag           */
+};
+
+int cparam_call_decode(struct cparam_call **prmp,
+		       const char *prm, struct re_printf *pf);
+
 /*
  * Custom headers
  */
@@ -1012,6 +1045,7 @@ struct tls  *uag_tls(void);
 struct sipsess_sock  *uag_sipsess_sock(void);
 struct sipevent_sock *uag_sipevent_sock(void);
 struct call *uag_call_find(const char *id);
+struct call *uag_call_find_pl(const struct pl *id);
 void uag_filter_calls(call_list_h *listh, call_match_h *matchh, void *arg);
 
 
@@ -1430,7 +1464,6 @@ int  audio_start_source(struct audio *a, struct list *ausrcl,
 			struct list *aufiltl);
 void audio_stop(struct audio *a);
 bool audio_started(const struct audio *a);
-void audio_set_hold(struct audio *au, bool hold);
 int  audio_set_conference(struct audio *au, bool conference);
 bool audio_is_conference(const struct audio *au);
 int  audio_encoder_set(struct audio *a, const struct aucodec *ac,
@@ -1862,9 +1895,9 @@ int peerconnection_add_video_track(struct peer_connection *pc,
 				   struct list *vidcodecl, enum sdp_dir dir);
 int  peerconnection_set_remote_descr(struct peer_connection *pc,
 				    const struct session_description *sd);
-int  peerconnection_create_offer(struct peer_connection *sess,
+int  peerconnection_create_offer(struct peer_connection *pc,
 				struct mbuf **mb);
-int  peerconnection_create_answer(struct peer_connection *sess,
+int  peerconnection_create_answer(struct peer_connection *pc,
 				 struct mbuf **mb);
 int  peerconnection_start_ice(struct peer_connection *pc);
 void peerconnection_close(struct peer_connection *pc);
